DTreeNode

DTreeNode()

Abstract base class for decision tree nodes.

Attributes

Name Description
model_config dict() -> new empty dictionary

Methods

Name Description
expected_value Return the expected value of this node.
rollback_rows Return tidy rollback rows for this node and descendants.
sample Generate outcome samples from this node.

expected_value

DTreeNode.expected_value(size=None, seed=None)

Return the expected value of this node.

rollback_rows

DTreeNode.rollback_rows(size=None, seed=None)

Return tidy rollback rows for this node and descendants.

sample

DTreeNode.sample(size=1, *, seed=None)

Generate outcome samples from this node.