MCOperation

MCOperation()

Serializable operations supported by Monte Carlo model expressions.

Attributes

Name Description
ABS Serializable operations supported by Monte Carlo model expressions.
ADD Serializable operations supported by Monte Carlo model expressions.
DIVIDE Serializable operations supported by Monte Carlo model expressions.
GREATER Serializable operations supported by Monte Carlo model expressions.
GREATER_EQUAL Serializable operations supported by Monte Carlo model expressions.
LESS Serializable operations supported by Monte Carlo model expressions.
LESS_EQUAL Serializable operations supported by Monte Carlo model expressions.
MULTIPLY Serializable operations supported by Monte Carlo model expressions.
NEGATIVE Serializable operations supported by Monte Carlo model expressions.
POSITIVE Serializable operations supported by Monte Carlo model expressions.
POWER Serializable operations supported by Monte Carlo model expressions.
SUBTRACT Serializable operations supported by Monte Carlo model expressions.
WHERE Serializable operations supported by Monte Carlo model expressions.
function Return the NumPy callable implementing this operation.

Methods

Name Description
from_function Return the serializable operation matching a NumPy callable.

from_function

MCOperation.from_function(op)

Return the serializable operation matching a NumPy callable.