PERT
PERT()PERT distribution as a stretched beta with concentration fixed at 4.
Methods
| Name | Description |
|---|---|
| elicit | Elicit a PERT distribution from min/mode/max values. |
| fit | Fit a PERT distribution using sample bounds and the PERT mean relation. |
elicit
PERT.elicit(min, mode, max, name=None)Elicit a PERT distribution from min/mode/max values.
fit
PERT.fit(data, name=None)Fit a PERT distribution using sample bounds and the PERT mean relation.
The concentration is fixed at 4, so the sample minimum and maximum define the bounds and the sample mean determines the implied mode via mean = (min + 4 * mode + max) / 6.